@@ -1,5 +1,5 @@
 package String::Validator::Language;
-$String::Validator::Language::VERSION = '1.95'; # TRIAL
+$String::Validator::Language::VERSION = '2.04'; # TRIAL
 # ABSTRACT: Languages for String::Validator
 
 use 5.008;
@@ -18,7 +18,7 @@ String::Validator::Language - Languages for String::Validator
 
 =head1 VERSION
 
-version 1.95
+version 2.04
 
 =head1 SYNOPSIS
 
@@ -35,6 +35,17 @@ Provides Language Customizations for String Validator
  LANGUAGE | MODULE                              | Supported Modules
  ---------|-------------------------------------|-----------------------------
  French   | String::Validator::Language::FR     | common, password
+ English  | String::Validator::Language::EN     | *
+
+=head2 Language::EN
+
+English is the default language, all of the messages from all of the modules
+are in English, use it as a template for Language Customization when creating
+new Language Modules.
+
+=head1 Acknowledgements
+
+French translation submitted by Antoine Gallavardin.
 
 =cut
 
